#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-diff
version:              1.1.0.9
visibility:           public
id:                   aeson-diff-1.1.0.9-BrxIZVcJXGjshpiDXe9FG
key:                  aeson-diff-1.1.0.9-BrxIZVcJXGjshpiDXe9FG
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           me@thomas-sutton.id.au
author:               Thomas Sutton
homepage:             https://github.com/thsutton/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  6782ce05d8a4da3b6bf106955c7e565a
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-8.10.5/site-local/aeson-diff-1.1.0.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/aeson-diff-1.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/aeson-diff-1.1.0.9
hs-libraries:         HSaeson-diff-1.1.0.9-BrxIZVcJXGjshpiDXe9FG
depends:
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs base-4.14.2.0
    bytestring-0.10.12.0
    edit-distance-vector-1.0.0.4-IEvnkBFGWfEDoangoGIcxQ
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo mtl-2.2.2
    scientific-0.3.7.0-Ea1GK6jx8XDEEsfAKxwFym text-1.2.4.1
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

